@@ -650,10 +650,11 @@ cb_plot_family_menu_create (char const *id, GogPlotFamily *family,
 	if (g_hash_table_size (family->types) <= 0)
 		return;
 
-	axis_set = gog_chart_get_axis_set (GOG_CHART (closure->state->prop_object));
+	axis_set = gog_chart_get_axis_set (GOG_CHART (closure->state->prop_object)) 
+				& GOG_AXIS_SET_FUNDAMENTAL;
 
-	if (axis_set != GOG_AXIS_SET_UNKNOWN &&
-	    family->axis_set != axis_set)
+	if (axis_set != GOG_AXIS_SET_FUNDAMENTAL &&
+	    (family->axis_set & GOG_AXIS_SET_FUNDAMENTAL) != axis_set)
 		return;
 
 	menu = gtk_image_menu_item_new_with_label (_(family->name));
@@ -1028,9 +1029,6 @@ cb_canvas_select_item (FooCanvas *canvas, GdkEvent *event,
 
 			g_return_val_if_fail (FOO_IS_CANVAS (canvas), FALSE);
 
-			if (canvas->current_item == NULL)
-				return FALSE;
-
 			g_object_get (G_OBJECT(s->sample_graph_item), "x", &item_x, "y", &item_y, NULL);
 			gog_graph_view_handle_event (s->graph_view, (GdkEvent *) event, 
 						     item_x * canvas->pixels_per_unit,
@@ -1102,7 +1100,7 @@ cb_graph_selection_changed (GogGraphView *view, GogObject *gobj,
 static void
 graph_guru_init_format_page (GraphGuruState *s)
 {
-	GtkWidget *w;
+	GtkWidget *w, *canvas;
 	GtkTreeViewColumn *column;
 	GogRenderer *rend;
 
@@ -1134,20 +1132,22 @@ graph_guru_init_format_page (GraphGuruState *s)
 		G_CALLBACK (cb_prec_last), s);
 
 	/* Load up the sample view and make it fill the entire canvas */
-	w = glade_xml_get_widget (s->gui, "sample_canvas");
+	w = glade_xml_get_widget (s->gui, "sample-alignment");
+	canvas = foo_canvas_new ();
+	gtk_container_add (GTK_CONTAINER (w), canvas);
 	s->sample_graph_item = foo_canvas_item_new (
-		foo_canvas_root (FOO_CANVAS (w)), GOG_CONTROL_FOOCANVAS_TYPE,
+		foo_canvas_root (FOO_CANVAS (canvas)), GOG_CONTROL_FOOCANVAS_TYPE,
 		"model", s->graph,
 		NULL);
-	gtk_widget_add_events (w, GDK_POINTER_MOTION_HINT_MASK);
-	cb_sample_plot_resize (FOO_CANVAS (w), &w->allocation, s);
-	g_signal_connect (G_OBJECT (w),
+	gtk_widget_add_events (canvas, GDK_POINTER_MOTION_HINT_MASK);
+	cb_sample_plot_resize (FOO_CANVAS (canvas), &canvas->allocation, s);
+	g_signal_connect (G_OBJECT (canvas),
 		"size_allocate",
 		G_CALLBACK (cb_sample_plot_resize), s);
-	g_signal_connect_after (G_OBJECT (w),
+	g_signal_connect_after (G_OBJECT (canvas),
 		"event",
 		G_CALLBACK (cb_canvas_select_item), s);
-	gtk_widget_show (w);
+	gtk_widget_show (canvas);
 	
 	/* Connect to selection-changed signal of graph view */
 	g_object_get (G_OBJECT (s->sample_graph_item), "renderer", &rend, NULL);
@@ -1429,7 +1429,7 @@ graph_guru_init (GraphGuruState *s)
 	s->button_navigate = graph_guru_init_button (s, "button_navigate");
 	s->button_ok	   = graph_guru_init_ok_button (s);
 
-#warning FIXME move the docs down to libgoffice
+/* FIXME FIXME FIXME move the docs down to libgoffice */
 	go_gtk_help_button_init	(glade_xml_get_widget (s->gui, "help_button"),
 				 go_sys_data_dir (), "gnumeric",
 				 "sect-graphics-plots");
